# zRAG
zero-RAG


[![Python Package](https://github.com/Ak-Gautam/sRAG/actions/workflows/python-package.yml/badge.svg)](https://github.com/Ak-Gautam/sRAG/actions/workflows/python-package.yml)
[![codecov](https://codecov.io/gh/Ak-Gautam/sRAG/branch/main/graph/badge.svg)](https://codecov.io/gh/Ak-Gautam/sRAG)
[![PyPI version](https://badge.fury.io/py/zrag.svg)](https://badge.fury.io/py/zrag)
[![Python Versions](https://img.shields.io/pypi/pyversions/zrag.svg)](https://pypi.org/project/zrag/)

A lightweight RAG implementation to quickly run it with oss models and vector stores. Simple and easy to use.
